@@ -84,7 +84,7 @@ def catcher():
             % sys.exc_info()[2].tb_next.tb_next.tb_frame.f_code.co_name
         )
         print(
-            "Previous frame locals (module) are",
+            "Third traceback locals (function) are",
             displayDict(sys.exc_info()[2].tb_next.tb_next.tb_frame.f_locals),
         )
 
