@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,9 +15,8 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+from foo import bar, bar2, not_overloaded
 
-from foo import bar, not_overloaded
 print(bar, not_overloaded)
 
-from foo import bar2, not_overloaded
-print( bar2 )
+print(bar2)
