@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Software where
@@ -17,7 +17,9 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-import Pmw  # @UnresolvedImport
+import Pmw
 
 # nuitka-skip-unless-expression: __import__("Tkinter" if sys.version_info[0] < 3 else "tkinter")
 # nuitka-skip-unless-imports: Pmw
+
+print("OK.")
\ No newline at end of file
